package com.jiuqi.util;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.io.UnsupportedEncodingException;

/* loaded from: com_jiuqi_util.jar:com/jiuqi/util/Stream.class */
public abstract class Stream {
    private boolean encode = true;
    private String charset = "GBK";
    private static final int BUFF_SIZE = 1024;
    public static final int SEEK_ORIGIN_START = 0;
    public static final int SEEK_ORIGIN_CURRENT = 1;
    public static final int SEEK_ORIGIN_END = 2;

    public abstract void setSize(long j) throws StreamException;

    public abstract int read(byte[] bArr, int i, int i2) throws StreamException;

    public abstract byte read() throws StreamException;

    public abstract int write(byte[] bArr, int i, int i2) throws StreamException;

    public abstract void write(byte b) throws StreamException;

    public abstract long seek(long j, int i) throws StreamException;

    public void setUseEncode(boolean useEncode) {
        this.encode = useEncode;
    }

    public boolean getUseEncode() {
        return this.encode;
    }

    public void setCharset(String encodeCharset) {
        if (encodeCharset != null && encodeCharset.length() != 0) {
            this.charset = encodeCharset;
        }
    }

    public String getCharset() {
        return this.charset;
    }

    public void readBuffer(byte[] buffer, int pos, int count) throws StreamException {
        if (count != 0 && read(buffer, pos, count) != count) {
            throw new StreamException(StreamException.STREAM_READERROR);
        }
    }

    public void writeBuffer(byte[] buffer, int pos, int count) throws StreamException {
        if (count != 0 && write(buffer, pos, count) != count) {
            throw new StreamException(StreamException.STREAM_WRITEERROR);
        }
    }

    public long copyFrom(Stream source, long count) throws StreamException {
        int bufSize;
        int i;
        if (source == null) {
            return 0L;
        }
        if (count == 0) {
            source.setPosition(0L);
            count = source.getSize();
        }
        if (count > 1024) {
            bufSize = BUFF_SIZE;
        } else {
            bufSize = (int) count;
        }
        byte[] buffer = new byte[BUFF_SIZE];
        while (count != 0) {
            if (count > bufSize) {
                i = bufSize;
            } else {
                i = (int) count;
            }
            int n = i;
            source.readBuffer(buffer, 0, n);
            writeBuffer(buffer, 0, n);
            count -= n;
        }
        return 0L;
    }

    public long copyFrom(InputStream stream, long size) throws StreamException, IOException {
        int b;
        if (stream == null) {
            return 0L;
        }
        long readcount = 0;
        if (size == 0) {
            byte[] buf = new byte[BUFF_SIZE];
            do {
                b = stream.read(buf);
                if (b > 0) {
                    write(buf, 0, b);
                    readcount += b;
                }
            } while (b > 0);
            while (b > 0) {
                b = stream.read(buf);
                if (b > 0) {
                    write(buf, 0, b);
                }
            }
        } else {
            byte[] buffer = new byte[BUFF_SIZE];
            do {
                int blockSize = size > 1024 ? BUFF_SIZE : (int) size;
                int readSize = stream.read(buffer, 0, blockSize);
                write(buffer, 0, readSize);
                readcount += readSize;
                size -= readSize;
                if (readSize <= 0) {
                    break;
                }
            } while (size > 0);
        }
        return readcount;
    }

    public long copyTo(OutputStream stream, long size) throws StreamException, IOException {
        long writecount = 0;
        byte[] buffer = new byte[BUFF_SIZE];
        int writesize = read(buffer, 0, BUFF_SIZE);
        while (writesize > 0 && size > 0) {
            stream.write(buffer, 0, writesize);
            writesize = read(buffer, 0, BUFF_SIZE);
            writecount += writesize;
            size -= writesize;
        }
        return writecount;
    }

    public byte[] getBytes() throws StreamException {
        long oldPos = getPosition();
        try {
            byte[] rt = new byte[(int) getSize()];
            setPosition(0L);
            read(rt, 0, rt.length);
            return rt;
        } finally {
            setPosition(oldPos);
        }
    }

    public long getSize() throws StreamException {
        long pos = seek(0L, 1);
        long r = seek(0L, 2);
        seek(pos, 0);
        return r;
    }

    public long getPosition() throws StreamException {
        return seek(0L, 1);
    }

    public void setPosition(long pos) throws StreamException {
        seek(pos, 0);
    }

    public short readShort() throws StreamException {
        int b1 = read() & 255;
        int b2 = read() & 255;
        return (short) ((b2 << 8) + (b1 << 0));
    }

    public int readWord() throws StreamException {
        int b1 = read() & 255;
        int b2 = read() & 255;
        return (b2 << 8) + (b1 << 0);
    }

    public int readInt() throws StreamException {
        int b1 = read() & 255;
        int b2 = read() & 255;
        int b3 = read() & 255;
        int b4 = read() & 255;
        return (b4 << 24) + (b3 << 16) + (b2 << 8) + (b1 << 0);
    }

    public float readFloat() throws StreamException {
        return Float.intBitsToFloat(readInt());
    }

    public double readDouble() throws StreamException {
        return Double.longBitsToDouble(readLong());
    }

    public String readString(int length) throws StreamException {
        byte[] str = new byte[length];
        read(str, 0, length);
        return decodeString(str);
    }

    public String decodeString(byte[] data) {
        if (this.encode) {
            try {
                return new String(data, this.charset);
            } catch (UnsupportedEncodingException unused) {
                return new String(data);
            }
        }
        return new String(data);
    }

    public String readStringBySize() throws StreamException {
        int len = readInt();
        if (len == 0) {
            return null;
        }
        return readString(len);
    }

    public boolean readBool() throws StreamException {
        return read() > 0;
    }

    public long readLong() throws StreamException {
        long b1 = read() & 255;
        long b2 = read() & 255;
        long b3 = read() & 255;
        long b4 = read() & 255;
        long b5 = read() & 255;
        long b6 = read() & 255;
        long b7 = read() & 255;
        long b8 = read();
        return (b8 << 56) + (b7 << 48) + (b6 << 40) + (b5 << 32) + (b4 << 24) + (b3 << 16) + (b2 << 8) + (b1 << 0);
    }

    public void writeShort(short value) throws StreamException {
        write((byte) ((value >>> 0) & 255));
        write((byte) ((value >>> 8) & 255));
    }

    public void writeWord(int value) throws StreamException {
        write((byte) ((value >>> 0) & 255));
        write((byte) ((value >>> 8) & 255));
    }

    public void writeInt(int value) throws StreamException {
        write((byte) ((value >>> 0) & 255));
        write((byte) ((value >>> 8) & 255));
        write((byte) ((value >>> 16) & 255));
        write((byte) ((value >>> 24) & 255));
    }

    public void writeLong(long value) throws StreamException {
        write((byte) ((value >>> 0) & 255));
        write((byte) ((value >>> 8) & 255));
        write((byte) ((value >>> 16) & 255));
        write((byte) ((value >>> 24) & 255));
        write((byte) ((value >>> 32) & 255));
        write((byte) ((value >>> 40) & 255));
        write((byte) ((value >>> 48) & 255));
        write((byte) ((value >>> 56) & 255));
    }

    public void writeFloat(float value) throws StreamException {
        writeInt(Float.floatToIntBits(value));
    }

    public void writeDouble(double value) throws StreamException {
        writeLong(Double.doubleToLongBits(value));
    }

    public void writeBool(boolean value) throws StreamException {
        byte b = value ? (byte) 1 : (byte) 0;
        write(b);
    }

    public void writeString(String value) throws StreamException {
        byte[] b = encodeString(value);
        write(b, 0, b.length);
    }

    public byte[] encodeString(String value) {
        if (value == null) {
            return null;
        }
        if (this.encode) {
            try {
                return value.getBytes(this.charset);
            } catch (UnsupportedEncodingException unused) {
                return value.getBytes();
            }
        }
        return value.getBytes();
    }

    public void writeStringWithSize(String value) throws StreamException {
        if (value == null) {
            writeInt(0);
            return;
        }
        byte[] b = encodeString(value);
        writeInt(b.length);
        write(b, 0, b.length);
    }

    public void loadFromFile(String fileName) throws StreamException, IOException {
        InputStream source = new FileInputStream(fileName);
        try {
            loadFromStream(source);
        } finally {
            source.close();
        }
    }

    public void loadFromStream(InputStream inStream) throws StreamException, IOException {
        copyFrom(inStream, 0L);
    }

    public void saveToFile(String fileName) throws StreamException, IOException {
        OutputStream dest = new FileOutputStream(fileName);
        try {
            saveToStream(dest);
        } finally {
            dest.close();
        }
    }

    public void saveToStream(OutputStream outStream) throws StreamException, IOException {
        setPosition(0L);
        copyTo(outStream, getSize());
    }
}
